# dadosSPF

## Getting Started
#### Dependencies
Você precisa do Python 3.7 ou posterior para usar dadosSPF.
Você pode encontrá-lo em [python.org] (https://www.python.org/).
Você precisa do PySpark 2.4.7 para usar dadosSPF.
Você pode encontrá-lo em [spark.apache.org] (https://spark.apache.org/docs/latest/api/python/).

You also need pandas, holidays and impyla packages, which is available from [PyPI](https://pypi.org). If you have pip, just run:
'''
pip install pandas
pip install holidays
pip install impyla
pip install unidecode
'''
#### Installation
Clone this repo to your local machine using:
'''
git clone https://gitlab.com.br/dados-migracao/dadosSPF
'''

## Features
- Pacote de conexção e ferramentas de consulmo de dados
- Pacote de ferramentas uteis
